fars_summarize_years: Summarize fars data

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

This function gets an array of string or int with years and returns how many fars data it happened by month of a year

Usage

1

Arguments

years

Vector of string or integer containing the years desired to be read

Value

This function returns a data structure of type tbl_df

Examples

1
## Not run: fars_summarize_years(c(2014, 2015))

danielfsilva88/ex4fars documentation built on April 5, 2020, 10:07 p.m.