Description Usage Arguments Value Examples
View source: R/fars_functions.R
This function gets an array of string or int with years and returns how many fars data it happened by month of a year
1 | fars_summarize_years(years)
|
years |
Vector of string or integer containing the years desired to be read |
This function returns a data structure of type tbl_df
1 | ## Not run: fars_summarize_years(c(2014, 2015))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.